@@ -2,10 +2,13 @@ use strict;
 use warnings;
 package MetaCPAN::Client::Release;
 # ABSTRACT: A Release data object
-$MetaCPAN::Client::Release::VERSION = '2.008001';
+$MetaCPAN::Client::Release::VERSION = '2.009000';
 use Moo;
+use Ref::Util qw< is_hashref >;
+use JSON::MaybeXS qw< decode_json >;
 
-with 'MetaCPAN::Client::Role::Entity';
+with 'MetaCPAN::Client::Role::Entity',
+     'MetaCPAN::Client::Role::HasUA';
 
 my %known_fields = (
     scalar => [qw<
@@ -55,6 +58,15 @@ foreach my $field (@known_fields) {
 
 sub _known_fields { return \%known_fields }
 
+sub changes {
+    my $self = shift;
+    my $url  = sprintf "https://fastapi.metacpan.org/changes/%s/%s", $self->author, $self->name;
+    my $res = $self->ua->get($url);
+    return unless is_hashref($res);
+    my $content = decode_json $res->{'content'};
+    return $content->{'content'};
+}
+
 sub metacpan_url {
     my $self = shift;
     sprintf( "https://metacpan.org/release/%s/%s", $self->author, $self->name )
@@ -74,7 +86,7 @@ MetaCPAN::Client::Release - A Release data object
 
 =head1 VERSION
 
-version 2.008001
+version 2.009000
 
 =head1 SYNOPSIS
 
@@ -219,6 +231,10 @@ the count of that particular result on CPAN Testers for this release.
 
 =head1 METHODS
 
+=head2 changes
+
+Returns the Changes text for the release.
+
 =head2 metacpan_url
 
 Returns a link to the release page on MetaCPAN.
